@@ -1,6 +1,6 @@
 #' Compile a .dll/.so from source.
 #'
-#' \code{compile_dll} performs a fake R CMD install so should code that
+#' \code{compile_dll} performs a fake R CMD install so code that
 #' works here should work with a regular install (and vice versa).
 #'
 #' During compilation, debug flags are set with
@@ -29,7 +29,9 @@ compile_dll <- function(pkg = ".", quiet = FALSE) {
 
   # Mock install the package to generate the DLL
   if (!quiet) message("Re-compiling ", pkg$package)
-  inst <- install_min(pkg, tempdir(), components = "libs",
+  install_dir <- tempfile("devtools_install_")
+  dir.create(install_dir)
+  inst <- install_min(pkg, install_dir, components = "libs",
     args = if (needs_clean(pkg)) "--preclean",
     quiet = quiet)
 
