@@ -129,7 +129,7 @@ use_travis <- function(pkg = ".") {
   message("Adding .travis.yml to ", pkg$package, ". Next: \n",
     " * Turn on travis for this repo at https://travis-ci.org/profile\n",
     " * Add a travis shield to your README.md:\n",
-    "[![Build Status]",
+    "[![Travis-CI Build Status]",
        "(https://travis-ci.org/", gh$username, "/", gh$repo, ".png?branch=master)]",
        "(https://travis-ci.org/", gh$username, "/", gh$repo, ")"
   )
@@ -145,6 +145,36 @@ use_travis <- function(pkg = ".") {
 #' @export
 add_travis <- use_travis
 
+#' @rdname infrastructure
+#' @section \code{use_appveyor}:
+#' Add basic AppVeyor template to a package. Also adds \code{appveyor.yml} to
+#' \code{.Rbuildignore} so it isn't included in the built package.
+#' @export
+use_appveyor <- function(pkg = ".") {
+  pkg <- as.package(pkg)
+
+  path <- file.path(pkg$path, "appveyor.yml")
+  if (file.exists(path)) {
+    stop("appveyor.yml already exists", call. = FALSE)
+  }
+
+  gh <- github_info(pkg)
+  message("Adding appveyor.yml to ", pkg$package, ". Next: \n",
+          " * Turn on AppVeyor for this repo at https://ci.appveyor.com/projects\n",
+          " * Add an AppVeyor shield to your README.md:\n",
+          "[![AppVeyor Build Status]",
+          "(https://ci.appveyor.com/api/projects/status/github/", gh$username, "/", gh$repo, "?branch=master)]",
+          "(https://ci.appveyor.com/project/", gh$username, "/", gh$repo, ")"
+  )
+
+  template_path <- system.file("templates/appveyor.yml", package = "devtools")
+  file.copy(template_path, path)
+
+  add_build_ignore(pkg, "appveyor.yml")
+
+  invisible(TRUE)
+}
+
 #' @rdname infrastructure
 #' @section \code{use_package_doc}:
 #' Adds a roxygen template for package documentation
@@ -363,6 +393,113 @@ use_build_ignore <- function(files, escape = TRUE, pkg = ".") {
   invisible(TRUE)
 }
 
+#' Add a git hook.
+#'
+#' @param hook Hook name. One of "pre-commit", "prepare-commit-msg",
+#'   "commit-msg", "post-commit", "applypatch-msg", "pre-applypatch",
+#'   "post-applypatch", "pre-rebase", "post-rewrite", "post-checkout",
+#'   "post-merge", "pre-push", "pre-auto-gc".
+#' @param script Text of script to run
+#' @param pkg package description, can be path or package name.  See
+#'   \code{\link{as.package}} for more information
+#' @export
+#' @family infrastructure
+#' @keywords internal
+use_git_hook <- function(hook, script, pkg = ".") {
+  pkg <- as.package(pkg)
+
+  hook_dir <- file.path(pkg$path, ".git", "hooks")
+  if (!file.exists(hook_dir)) {
+    stop("This project doesn't use git", call. = FALSE)
+  }
+
+  hook_path <- file.path(hook_dir, hook)
+  writeLines(script, hook_path)
+  Sys.chmod(hook_path, "0744")
+}
+
+#' Use README.Rmd
+#'
+#' This creates `README.Rmd` from template and adds to \code{.Rbuildignore}.
+#'
+#' @param hook Hook name. One of "pre-commit", "prepare-commit-msg",
+#'   "commit-msg", "post-commit", "applypatch-msg", "pre-applypatch",
+#'   "post-applypatch", "pre-rebase", "post-rewrite", "post-checkout",
+#'   "post-merge", "pre-push", "pre-auto-gc".
+#' @param script Text of script to run
+#' @param pkg package description, can be path or package name.  See
+#'   \code{\link{as.package}} for more information
+#' @export
+#' @family infrastructure
+#' @keywords internal
+use_readme_rmd <- function(pkg = ".") {
+  pkg <- as.package(pkg)
+
+  readme_path <- file.path(pkg$path, "README.Rmd")
+  template <- render_template("README.Rmd")
+
+  if (!file.exists(readme_path)) {
+    message("Creating README.Rmd")
+    writeLines(template, readme_path)
+  } else {
+    rule("README.Rmd exists. Please check that it starts with:")
+    message(template)
+    rule()
+  }
+  use_build_ignore("README.Rmd", pkg = pkg)
+  use_build_ignore("^README-*\\.png$", escape = FALSE, pkg = pkg)
+
+  if (uses_git(pkg) && file.exists(pkg$path, ".git", "hooks", "pre-commit")) {
+    message("Adding pre-commit hook")
+    use_git_hook("pre-commit", render_template("readme-rmd-pre-commit.sh"),
+      pkg = pkg)
+  }
+
+  invisible(TRUE)
+}
+
+#' @rdname infrastructure
+#' @section \code{use_revdep}:
+#' Add \code{revdep} directory and basic check template.
+#' @export
+#' @aliases add_travis
+use_revdep <- function(pkg = ".") {
+  pkg <- as.package(pkg)
+
+  message("Creating revdep/ & adding to .Rbuildignore")
+  dir.create(file.path(pkg$path, "revdep"), showWarnings = FALSE)
+  use_build_ignore("revdep", pkg = pkg)
+
+  message("Add revdep subdirectories to .gitigore")
+  path <- file.path(pkg$path, "revdep", ".gitignore")
+  union_write(path, "**/")
+
+  if (!file.exists("revdep/check.R")) {
+    message("Adding revdep/check.R template")
+    writeLines(render_template("revdep.R", list(name = pkg$package)),
+      file.path(pkg$path, "revdep", "check.R"))
+  }
+}
+
+#' @rdname infrastructure
+#' @section \code{use_cran_comments}:
+#' Add \code{cran-comments.md} template.
+#' @export
+#' @aliases add_travis
+use_cran_comments <- function(pkg = ".") {
+  pkg <- as.package(pkg)
+
+  use_build_ignore("cran-comments.md")
+
+  comments <- file.path(pkg$path, "cran-comments.md")
+  if (file.exists(comments))
+    stop("cran-comments.md already exists", call. = FALSE)
+
+  message("Adding cran-comments.md template")
+  writeLines(render_template("cran-comments.md", list()), comments)
+  invisible()
+}
+
 add_build_ignore <- function(pkg = ".", files, escape = TRUE) {
   use_build_ignore(files, escape = escape, pkg = pkg)
 }
@@ -386,3 +523,4 @@ union_write <- function(path, new_lines) {
   all <- union(lines, new_lines)
   writeLines(all, path)
 }
+
