@@ -46,7 +46,9 @@ release <- function(pkg = ".", check = TRUE) {
   new_pkg <- is.null(cran_version)
 
   if (check) {
-    check(pkg, cran = TRUE, check_version = TRUE)
+    check(pkg, cran = TRUE, check_version = TRUE, manual = TRUE)
+    release_checks(pkg)
+
     if (yesno("Was package check successful?"))
       return(invisible())
 
@@ -67,9 +69,9 @@ release <- function(pkg = ".", check = TRUE) {
     }
   }
 
-  policies <- paste("Have you read and do you agree to the the CRAN policies?",
-    "\n(http://cran.r-project.org/web/packages/policies.html)")
-  if (yesno(policies))
+  rule("cran-comments.md ")
+  cat(cran_comments(pkg), "\n\n")
+  if (yesno("Are the CRAN submission comments correct?"))
     return(invisible())
 
   if (yesno("Have you checked on win-builder (with build_win())?"))
@@ -107,11 +109,6 @@ release <- function(pkg = ".", check = TRUE) {
   if (yesno("Is your email address ", maintainer(pkg)$email, "?"))
     return(invisible())
 
-  rule("cran-comments.md ")
-  cat(cran_comments(pkg), "\n\n")
-  if (yesno("Are the CRAN submission comments correct?"))
-    return(invisible())
-
   if (yesno("Ready to submit?"))
     return(invisible())
 
@@ -220,8 +217,10 @@ cran_comments <- function(pkg = ".") {
   path <- file.path(pkg$path, "cran-comments.md")
   if (!file.exists(path)) {
     stop("Can't find cran-comments.md in ", pkg$package, ".\n",
-      "This file for comments for package submission and must exist.\n",
-      "Please create and add to .Rbuildignore (with add_build_ignore())",
+      "This file gives CRAN volunteers comments about the submission,\n",
+      "and it must exist.  Please create it using this guide:\n",
+      "http://r-pkgs.had.co.nz/release.html#release-check",
+      "Then run use_build_ignore('cran-comments.md')",
       call. = FALSE)
   }
 
@@ -233,7 +232,7 @@ cran_submission_url <- "http://xmpalantir.wu.ac.at/cransubmit/index2.php"
 #' Submit a package to CRAN.
 #'
 #' This uses the new CRAN web-form submission process. After submission, you
-#' will recieve an email asking you to confirm submission - this is used
+#' will receive an email asking you to confirm submission - this is used
 #' to check that the package is submitted by the maintainer.
 #'
 #' It's recommend that you use \code{\link{release}()} rather than this
@@ -249,7 +248,7 @@ submit_cran <- function(pkg = ".") {
   comments <- cran_comments(pkg)
 
   message("Building")
-  built_path <- build(pkg, tempdir())
+  built_path <- build(pkg, tempdir(), manual = TRUE)
   message("File size: ", file.info(built_path)$size, " bytes")
 
   # Initial upload ---------
