@@ -20,7 +20,8 @@ test_that("system.file returns correct values when used with load_all", {
   shim_ns <- ns_env("testShim")
 
   # The devtools::system.file function should return modified values.
-  files <- system.file(c("A.txt", "B.txt", "C.txt", "D.txt"), package = "testShim")
+  files <- shim_system.file(c("A.txt", "B.txt", "C.txt", "D.txt"),
+                            package = "testShim")
   files <- expand_path(files)
 
   expect_true(all(last_n(files[[1]], 3) == c("testShim", "inst", "A.txt")))
@@ -32,17 +33,17 @@ test_that("system.file returns correct values when used with load_all", {
   expect_equal(length(files), 3)
 
   # If all files are not present, return ""
-  files <- system.file("nonexistent", package = "testShim")
+  files <- shim_system.file("nonexistent", package = "testShim")
   expect_equal(files, "")
 
   # Test packages loaded the usual way - should just pass through to
   # base::system.file
   expect_identical(base::system.file("Meta", "Rd.rds", package = "stats"),
-    system.file("Meta", "Rd.rds", package = "stats"))
+    shim_system.file("Meta", "Rd.rds", package = "stats"))
   expect_identical(base::system.file("INDEX", package = "stats"),
-    system.file("INDEX", package = "stats"))
+    shim_system.file("INDEX", package = "stats"))
   expect_identical(base::system.file("nonexistent", package = "stats"),
-    system.file("nonexistent", package = "stats"))
+    shim_system.file("nonexistent", package = "stats"))
 
   unload("testShim")
 })
@@ -54,10 +55,10 @@ test_that("Shimmed system.file returns correct values when used with load_all",
 
   # Make sure the version of system.file inserted into the namespace's imports
   # is the same as devtools::system.file
-  expect_identical(get("system.file", envir = shim_ns), devtools::system.file)
+  expect_identical(get("system.file", envir = shim_ns), shim_system.file)
 
   # Another check
-  expect_identical(get_system.file(), devtools::system.file)
+  expect_identical(get_system.file(), shim_system.file)
 
   unload("testShim")
 })
